Test Type
open | ../tests/html/test_type_page1.html |
verifyValue | username |
shiftKeyDown |  |
type | username | x
verifyValue | username | X
shiftKeyUp |  |
type | username | TestUserWithLongName
verifyValue | username | TestUserWi
type | username | TestUser
verifyValue | username | TestUser
verifyValue | password |
type | password | testUserPasswordIsVeryLong
verifyValue | password | testUserPasswordIsVe
type | password | testUserPassword
verifyValue | password | testUserPassword
clickAndWait | submitButton |
verifyTextPresent | Welcome, TestUser! |